@@ -75,6 +75,12 @@ $number = Number::Phone->new('+447979866975');
 ok($number->is_mobile(), "mobiles correctly identified");
 ok(defined($number->is_fixed_line()) && !$number->is_fixed_line(), "mobiles are identified as not fixed lines");
 
+skip_if_mocked("can't check country when mocking is in place", 1, sub {
+    # 74576 is an IM prefix, the rest of 7457 is UK
+    $number = Number::Phone->new('+447457500000');
+    is($number->country(), 'UK', "most of +44 7457 is recognised as UK. See weird little islands tests for the exception");
+});
+
 $number = Number::Phone->new('+447693912345');
 ok($number->is_pager(), "pagers correctly identified");
 
@@ -89,7 +95,7 @@ skip_if_mocked("libphonenumber doesn't know about location/operators/network-ser
   $number = Number::Phone->new('+448450033845');
   ok($number->is_specialrate(), "special-rate numbers correctly identified");
 
-  $number = Number::Phone->new('+449088761234');
+  $number = Number::Phone->new('+449088801234');
   ok($number->is_adult() && $number->is_specialrate(), "0908 'adult' numbers correctly identified");
   $number = Number::Phone->new('+449090901234');
   ok($number->is_adult() && $number->is_specialrate(), "0909 'adult' numbers correctly identified");
@@ -101,7 +107,7 @@ skip_if_mocked("libphonenumber doesn't know about location/operators/network-ser
   ok($number->is_network_service(), "network service numbers correctly identified");
 
   $number = Number::Phone->new('+448450033845');
-  is($number->operator(), 'Edge Telecom Limited', "operators correctly identified");
+  is($number->operator(), 'GCI Network Solutions Limited', "operators correctly identified");
 
   $number = Number::Phone->new('+442087712924');
   subtest "geo numbers have correct location" => sub {
@@ -260,8 +266,8 @@ foreach my $invalid (qw(+4427593934500 +4420877129200 +4411320316000 +4411332500
 foreach my $tuple (
   [ 'Number::Phone'     => '+441954202020', '+44 1954 202020' ],
   [ 'Number::Phone::UK' => '01954202020',   '+44 1954 202020' ],
-  [ 'Number::Phone'     => '+441697384444', '+44 1697384444' ],
-  [ 'Number::Phone::UK' => '01697384444',   '+44 1697384444' ],
+  [ 'Number::Phone'     => '+441697384444', '+44 16973 84444' ],
+  [ 'Number::Phone::UK' => '01697384444',   '+44 16973 84444' ],
 ) {
   my($class, $number, $result) = @{$tuple};
   skip_if_mocked("Stubs aren't intended to be constructed directly", 1, sub {
